@@ -3,7 +3,7 @@ from .hubspot import BASE_URL
 from .hubspot import HEADERS
 
 
-def search_contacts_by_property_value(property_name, property_value, property_names, after=None):
+def search_contacts_by_property_value(property_name, property_value, property_names=None, after=None):
   filters = [
       {
           'propertyName': property_name,
